
"""

Kibrit
======

The module for watching SCM (git, hg, svn).
Use it for control a static's versions.

"""

__version__ = '0.1.5'
__project__ = __name__
__author__ = "Sinan Midillili <sinan@hipo.biz>"
__license__ = "BSD"